@@ -13,11 +13,6 @@ class BigNumber(object):
             return self.value == other.value and self.exp == other.exp
         return self.value == other
 
-    def __lt__(self, other):
-        if isinstance(other, BigNumber):
-            return self.value < other.value
-        return self.value < other
-
     def __gt__(self, other):
         if isinstance(other, BigNumber):
             return self.value > other.value
@@ -29,7 +24,7 @@ class BigNumber(object):
     @classmethod
     def from_value(cls, value, exp=18):
         bg = cls(0, exp)
-        bg.value = value
+        bg.value = int(value)
         return bg
 
     def to_number(self) -> float:
